#
# Conditional build:
%bcond_without	tests		# don't build and run tests
%bcond_without	system_libffi	# use system libffi (upstream 3.0.12 or gcc >= 4.8)

Summary:	Easy access to native shared libraries from Java
Summary(pl.UTF-8):	Prosty dostęp do natywnych bibliotek współdzielonych z poziomu Javy
Name:		java-jna
Version:	5.5.0
Release:	1
License:	LGPL v2.1 or Apache v2.0
Group:		Libraries/Java
#Source0Download: https://github.com/java-native-access/jna/releases
Source0:	https://github.com/java-native-access/jna/archive/%{version}/jna-%{version}.tar.gz
# Source0-md5:	12df44bb982fb1250687b58f8e23a0de
# Note: by default jna.jar contains versions of native libjnidispatch
# for many systems/architectures; this patch disables such packaging;
# we package libjnidispatch.so as normal native library instead
Patch0:		jna-nonative.patch
Patch1:		jna-soname.patch
Patch2:		jna-tmpdir.patch
Patch3:		jna-x32.patch
Patch4:		jna-no-aar.patch
URL:		https://github.com/java-native-access/jna/
%if %(locale -a | grep -q '^en_US$'; echo $?)%(locale -a | grep -q '^en_US\.utf8$'; echo $?)
BuildRequires:	glibc-localedb-all
%endif
BuildRequires:	ant >= 1.9.0
BuildRequires:	jpackage-utils
BuildRequires:	rpm-javaprov
BuildRequires:	rpmbuild(macros) >= 1.300
BuildRequires:	sed >= 4.0
BuildRequires:	unzip
%if %{with system_libffi}
# upstream version
BuildRequires:	libffi-devel >= 3.0.12
# gcc version (gcc 4.7.3 is not sufficient - missing ffi_prep_cif_var added in libffi 3.0.12)
BuildRequires:	libffi-devel >= 6:4.8
BuildRequires:	pkgconfig
%endif
%if %{with tests}
BuildRequires:	java-junit
BuildRequires:	ant-junit
%endif
Requires:	jpackage-utils
BuildRoot:	%{tmpdir}/%{name}-%{version}-root-%(id -u -n)

%description
JNA provides Java programs easy access to native shared libraries
(DLLs on Windows) without writing anything but Java code - no JNI or
native code is required.

%description -l pl.UTF-8
JNA pozwala na łatwy dostęp do natywnych bibliotek współdzielonych bez
pisania czegokolwiek co nie jest kodem Javy - nie jest potrzebne JNI
ani kod natywny.

%prep
%setup -q -n jna-%{version}
%patch0 -p1
%patch1 -p1
%patch2 -p1
%patch3 -p1
%patch4 -p1

%{__rm} -r dist/* lib/native/*.jar

%if %{with system_libffi}
# use system libffi
%{__sed} -i -e '/property name="dynlink\.native"/s/value="false"/value="true"/' build.xml
%endif
# optflags
%{__sed} -i -e '/property name="cflags_extra\.native"/s@value=""@value="%{rpmcflags}"@' build.xml

# ELFAnalyserTest fails when foreign native libraries are not present
%{__rm} test/com/sun/jna/ELFAnalyserTest.java

%build
# build seems to need iso-8859-1 locale (there are some 8bit-encoded characters in win32 sources)
export LC_ALL=en_US
%ant -DCC="%{__cc}" -Drelease=1 -Dbuild-native=true -Ddynlink.native=true dist

%if %{with tests}
# but tests require UTF-8
export LC_ALL=en_US.UTF-8
%ant -Drelease=1 test
%endif

%install
rm -rf $RPM_BUILD_ROOT
install -d $RPM_BUILD_ROOT{%{_javadir},%{_libdir}}

# jars
cp -p dist/jna.jar $RPM_BUILD_ROOT%{_javadir}/jna-%{version}.jar
ln -s jna-%{version}.jar $RPM_BUILD_ROOT%{_javadir}/jna.jar
cp -p dist/jna-platform.jar $RPM_BUILD_ROOT%{_javadir}/jna-platform-%{version}.jar
ln -s jna-platform-%{version}.jar $RPM_BUILD_ROOT%{_javadir}/jna-platform.jar
# native stub library
install build/native-linux-*/libjnidispatch.so $RPM_BUILD_ROOT%{_libdir}

%clean
rm -rf $RPM_BUILD_ROOT

%files
%defattr(644,root,root,755)
%doc CHANGES.md LICENSE OTHERS README.md TODO
%attr(755,root,root) %{_libdir}/libjnidispatch.so
%{_javadir}/jna-%{version}.jar
%{_javadir}/jna.jar
%{_javadir}/jna-platform-%{version}.jar
%{_javadir}/jna-platform.jar
%changelog
* Fri May 01 2020 PLD Linux Team <feedback@pld-linux.org>
- For complete changelog see: http://git.pld-linux.org/?p=packages/java-jna.git;a=log;h=auto/th/java-jna-5.5.0-1

* Fri May 01 2020 Jan Rękorajski <baggins@pld-linux.org> 9ff2d26
- up to 5.5.0

* Sat Jan 25 2020 Jan Rękorajski <baggins@pld-linux.org> ab5a1be
- drop obsolete and outdated manual inclusion of rpm macros

* Fri Jun 29 2018 Jakub Bogusz <qboosh@pld-linux.org> e11dd11
- updated to 4.5.1
- updated nonative,x32 patches
- added no-aar patch (skip building .aar archive)

* Tue Dec 15 2015 Jakub Bogusz <qboosh@pld-linux.org> a186247
- added x32 patch (use */libx32 libdirs, adjust alignments to conform x32 ABI)
- release 2

* Tue Oct 27 2015 Jacek Konieczny <j.konieczny@eggsoft.pl> 6b7011f
- override JNA tmpdir for tests

* Tue Oct 27 2015 Jacek Konieczny <j.konieczny@eggsoft.pl> ca1894a
- Version: 4.2.1, ant deps updated

* Mon Sep 23 2013 Elan Ruusamäe <glen@delfi.ee> 096b3ac
- unify github url

* Sun Sep 22 2013 Jakub Bogusz <qboosh@pld-linux.org> 3a80405
- new URLs, updated to 4.0
- added nonative patch, package libjnidispatch.so as normal library instead of pushing
  many variants of it into jna.jar
- added soname patch (fixes libjnidispatch.so soname)
- use system libffi if possible

* Sat Jul 23 2011 Jakub Bogusz <qboosh@pld-linux.org> baedfb4
- fixed tests bcond and its BRs
- translated pl into Polish

* Mon Jan 24 2011 sparky <sparky@pld-linux.org> 57b07b5
- BR: unzip

* Thu Dec 30 2010 Mateusz Korniak <matkor@pld-linux.org> ca40981
- Release 2. Turned default build way (with tests) back on, to allow build package.

* Wed Dec 29 2010 Elan Ruusamäe <glen@pld-linux.org> 167917b
- list ant targets to be able to skip tests

* Wed Dec 29 2010 Elan Ruusamäe <glen@pld-linux.org> 3425b2e
- gcc epoch is 6

* Wed Dec 29 2010 Elan Ruusamäe <glen@pld-linux.org> 08332eb
- ... and so is the classpath fill bogus

* Wed Dec 29 2010 Elan Ruusamäe <glen@pld-linux.org> ef0aacc
- ... and no need to remake .jar, template specs contain all possible ways to do things, not all you must do

* Wed Dec 29 2010 Elan Ruusamäe <glen@pld-linux.org> 677acdd
- source code format not in us-ascii clause is not true! copy from template and use brain would you?

* Wed Dec 29 2010 Elan Ruusamäe <glen@pld-linux.org> cab338e
- rename to java-jna (why add it to cvs with wrong name in first place?)

* Wed Dec 29 2010 Mateusz Korniak <matkor@pld-linux.org> fcd30bc
- Initial. Post 3.2.7 rev 1177.

